/*********************************************************************

  Descriptor.java (C) Kenneth J. Turner, Mark A. Jennings	19/11/01 V1.3

  This class serves as the way of loading and saving a scene. It handles
  both the write-out and the re-instantiation of all scene components

  KJT 04/06/01: disambiguated DataStream class

  KJT 13/08/01:

    o Minor tidy-up of code

    o Added "setName" method

*********************************************************************/

import extra.io.*;
import waba.io.*;
import waba.util.*;

public class Descriptor implements Storable {
  int boatCount;
  int markCount;
  Mark marks[];
  Boat boats[];
  int windDir;
  String fileName;

  // scenario parameters
  boolean boatStates[][];
  Vector overlapList[];
  int numPastOvls;
  boolean boatState[];
  String boatNames[];
  int xCoords[];
  int yCoords[];
  int headings[];
  int tacks[];

  int mxCoords[];
  int myCoords[];
  int mTack[];
  int mHeading[];

  // basic constructor

  public Descriptor () {
  }

  // main constructor: create the resources needed for load/save.

  public Descriptor (
    String name, Mark[] ms, Boat[] bs, int wind, int boatCount,
     int markCount) {
    this.boatCount = boatCount;
    this.markCount = markCount;
    marks = new Mark[markCount];
    boats = new Boat[boatCount];
    for (int i = 0; i < markCount ;i++)
      marks[i] = ms[i];
    for (int i = 0; i < boatCount; i++)
      boats[i] = bs[i];
    windDir = wind;
    fileName = name;
  }

  // these methods return the scene objects when called

  public Boat[] exportBoats () {
    return boats;
  }

  public Mark[] exportMarks () {
    return marks;
  }
  public byte getID () {
    return (byte) 123;
  }

  public Storable getInstance () {
    return new Descriptor ();
  }

  // load the scene details by means of instantiating new objects with
  // properties obtained from the DataStream

  public void loadState (extra.io.DataStream ds) {
    boatCount = ds.readInt ();
    markCount = ds.readInt ();
    marks = new Mark[markCount];
    boats = new Boat[boatCount];

    windDir = ds.readInt ();
    fileName = ds.readString ();

    boatStates = new boolean[boats.length][Boat.NUM_INTENTS];
    overlapList = new Vector[boats.length];
    boatNames = new String[boats.length];
    xCoords = new int[boats.length];
    yCoords = new int[boats.length];
    headings = new int[boats.length];
    tacks = new int[boats.length];

    for (int i = 0; i < boatCount; i++) {
      boatNames[i] = ds.readString ();			// boat names
      xCoords[i] = ds.readInt ();			// x coordinates
      yCoords[i] = ds.readInt ();			// y coordinates
      headings[i] = ds.readInt ();			// headings
      tacks[i] = ds.readInt ();			// tacks
      for (int j = 0; j < Boat.NUM_INTENTS; j++) {
	boatStates[i][j] = ds.readBoolean ();		// boat states
      }
      overlapList[i] = new Vector ();
      numPastOvls = ds.readInt ();
      for (int k = 0 ; k < numPastOvls; k++) {
	overlapList[i].add (ds.readString ());		// boat states
      }
      boats[i] = new Boat (xCoords[i], yCoords[i],
        headings[i], windDir, tacks[i], boatNames[i], overlapList[i]);
      boats[i].setStates (boatStates[i]);
    }

    mxCoords = new int[marks.length];
    myCoords = new int[marks.length];
    mTack = new int[marks.length];
    mHeading = new int[marks.length];

    for (int i = 0; i < markCount; i++) {
      mxCoords[i] = ds.readInt ();			// mx coordinates
      myCoords[i] = ds.readInt ();			// my coordinates
      mTack[i] = ds.readInt ();			// mTack
      mHeading[i] = ds.readInt ();			// m next
      marks[i] = new Mark (mxCoords[i], myCoords[i],
        mTack[i], windDir, mHeading[i]);
    }
  }

  // write out all the scene details to the DataStream

  public void saveState (extra.io.DataStream ds) {
    ds.writeInt (boatCount);
    ds.writeInt (markCount);
    ds.writeInt (windDir);
    ds.writeString (fileName);

    boatStates = new boolean[boats.length][Boat.NUM_INTENTS];
    overlapList = new Vector[boats.length];

    boatNames = new String[boats.length];
    xCoords = new int[boats.length];
    yCoords = new int[boats.length];
    headings = new int[boats.length];
    tacks = new int[boats.length];

    boolean[] boatState = new boolean[Boat.NUM_INTENTS];
    for (int i = 0; i < boats.length; i++) {
      for (int k = 0; k < Boat.NUM_INTENTS; k++)
	boatState[k] = boats[i].getState (k);
      boatNames[i] = boats[i].getName ();
      xCoords[i] = boats[i].getX ();
      yCoords[i] = boats[i].getY ();
      headings[i] = boats[i].getHeading ();
      tacks[i] = boats[i].getTack ();

      ds.writeString (boatNames[i]);
      ds.writeInt (xCoords[i]);
      ds.writeInt (yCoords[i]);
      ds.writeInt (headings[i]);
      ds.writeInt (tacks[i]);

      for (int j = 0; j < Boat.NUM_INTENTS; j++) {
	boatStates[i][j] = boatState[j];
	ds.writeBoolean (boatStates[i][j]);
      }

      overlapList[i] = boats[i].getOverlaps ();
      ds.writeInt (overlapList[i].getCount ());
      for (int k = 0; k < overlapList[i].getCount (); k++) {
	ds.writeString ((String) overlapList[i].get (k));
      }
    }

    mxCoords = new int[marks.length];
    myCoords = new int[marks.length];
    mTack = new int[marks.length];
    mHeading = new int[marks.length];
    for (int i = 0; i < markCount; i++) {
      mxCoords[i] = marks[i].getX ();
      myCoords[i] = marks[i].getY ();
      mTack[i] = marks[i].getTack ();
      mHeading[i] = marks[i].getHeading ();
      ds.writeInt (mxCoords[i]);
      ds.writeInt (myCoords[i]);
      ds.writeInt (mTack[i]);
      ds.writeInt (mHeading[i]);
    }
  }

  public void setName (String fileNameNew) {
    fileName = fileNameNew;
  }
}
