/*********************************************************************

  Help.java	(C) Kenneth J. Turner, Mark A. Jennings	21/08/02 V1.4

  This class defines the help pages for the main screens.

  KJT 21/08/02:

    o Help clarified for changing mark heading and map exit

*********************************************************************/

import waba.ui.*;
import waba.fx.*;
import waba.sys.*;

public class Help {
  private String helpEdit =
    "Click Prev or Next to select the\n" +
    "previous or next boat for editing.\n\n" +
    "The heading, name and status\n" +
    "(UPPER list) of the current boat are\n" +
    "shown. AC: sailing above proper\n" +
    "course, BC: sailing below proper\n" +
    "course, FN: finishing, GY: gybing, ST:\n" +
    "starting, TP: tacking to port, TS:\n" +
    "tacking to starboard, WA: was\n" +
    "ahead of others on entering the\n" +
    "two-lengths mark circle, WO: was\n" +
    "overlapped on the given boat.\n\n" +
    "Enter a new heading or name and\n" +
    "click Head or Name to change this.\n" +
    "Click Place to give the boat a new\n" +
    "position using the map screen. Click\n" +
    "Delete to remove the current boat.\n\n" +
    "Click on the LOWER list of status\n" +
    "values and then Add to add a status\n" +
    "setting to the boat. Note that some\n" +
    "of the status settings are mutually\n" +
    "exclusive. In the case of \"was\n" +
    "overlapped\", it is necessary to click\n" +
    "the boat that was overlapped using\n" +
    "the map screen. Add the status \"--\"\n" +
    "(clear) to indicate that a boat has\n" +
    "completed her manoeuvre (e.g.\n" +
    "starting or tacking). This has the\n" +
    "effect of clearing ALL status values.\n" +
    "Click on the LOWER list of status\n" +
    "values and then Clear to remove a\n" +
    "specific status from the boat.";
  private String helpFile =
    "Click on a scenario file in the list\n" +
    "to extract its name, otherwise\n" +
    "enter a name directly.\n\n" +
    "Click Load to retrieve the given\n" +
    "scenario. If the current scenario\n" +
    "is not saved, you will be prompted\n" +
    "to do this.\n\n" +
    "Click Save to store the current\n" +
    "scenario under the given name.\n\n" +
    "To rename a scenario, click on it in\n" +
    "the list, enter a new name, and\n" +
    "then click Name.\n\n" +
    "Click Delete to remove the scenario\n" +
    "with the given name. A deleted\n" +
    "scenario cannot be recovered.";
  private String helpMain =
    "The Boats line gives the current\n" +
    "number of boats. To add a boat,\n" +
    "enter its heading from 0 to 359\n" +
    "degrees inclusive (default 0) and its\n" +
    "name (default is the boat number).\n" +
    "Choose whether it is on port or\n" +
    "starboard tack (which must be\n" +
    "consistent with the wind direction).\n" +
    "Click Add, then tap the location\n" +
    "of the boat's mast on the map\n" +
    "screen. To change an existing boat,\n" +
    "click on Edit. Currently, only four\n" +
    "boats may be entered.\n\n" +
    "The Marks line gives the current\n" +
    "number of marks. To add a mark,\n" +
    "choose whether it is to be rounded\n" +
    "to port or starboard. Click Add,\n" +
    "then tap the mark's location on the\n" +
    "map screen. A second tap is required\n" +
    "to define the line to the next mark.\n" +
    "Click Delete to remove the most\n" +
    "recently added mark. Note that you\n" +
    "do not swap port/starboard for an\n" +
    "existing mark on this screen; drag\n" +
    "the mark heading on the map screen\n" +
    "instead. Note also that currently\n" +
    "only one mark may be defined.\n\n" +
    "Click Clear to discard the current\n" +
    "scenario and return to the start\n" +
    "screen. If the current scenario is not\n" +
    "saved, you will be prompted to do\n" +
    "this.\n\n" +
    "Click File to load, save, rename or\n" +
    "delete a scenario. Click Map to see\n" +
    "the map screen. Click Rules to see\n" +
    "the rules that apply in the current\n" +
    "scenario.\n\n" +
    "The Wind line gives the current wind\n" +
    "direction.";
   private String helpMap =
    "On the map, the wind direction is\n" +
    "shown by an arrow at the edge of\n" +
    "the screen. A boat is drawn with its\n" +
    "sail in the approximate position\n" +
    "relative to the wind. The boat's\n" +
    "name is shown, followed by an\n" +
    "asterisk if it is too close to another\n" +
    "boat or mark. In such a case, the\n" +
    "boat or mark must be repositioned.\n\n" +
    "The boat's name is followed by a list\n" +
    "of status values: AC (sailing\n" +
    "above proper course), BC (sailing\n" +
    "below proper course), FN (finishing),\n" +
    "GY (gybing), ST (starting), TP\n" +
    "(tacking to port), TS (tacking\n" +
    "to starboard), WA (was ahead\n" +
    "on approaching mark), WO (was\n" +
    "overlapped on given boat).\n\n" +
    "A mark is designated P(ort) or\n" +
    "S(tarboard) according to the side it\n" +
    "is rounded. A number indicates the\n" +
    "heading to the next mark. A mark is\n" +
    "surrounded by a two boat-lengths\n" +
    "circle.\n\n" +
    "On a Palm, the command letters\n" +
    "described below are entered in\n" +
    "either case using Graffiti in the\n" +
    "writing area. The same functions\n" +
    "are also available from the menu.\n\n" +
    "B (Boat): tap on the map to\n" +
    "  create a new boat. Boats will\n" +
    "  be numbered sequentially,\n" +
    "  but can be renamed later. If an\n" +
    "  automatically assigned number\n" +
    "  is already in use as a name, add\n" +
    "  the boat from the main screen.\n\n" +
    "C (Clear): clear the current\n" +
    "  scenario and restart. If the\n" +
    "  current scenario is not saved,\n" +
    "  you will be prompted to do this.\n\n" +
    "E (Edit): edit the current boats.\n\n" +
    "F (File): load, save, rename or\n" +
    "  delete scenario files.\n\n" +
    "H (Heading): drag near a boat's\n" +
    "  bow or near a mark. This\n" +
    "  results in a new heading (meaning,\n" +
    "  for a mark, the angle to the next\n" +
    "  mark). A boat will change tack as\n" +
    "  needed when its heading is altered.\n" +
    "  A mark will change to starboard/\n" +
    "  port rounding if dragged clockwise/\n" +
    "  anticlockwise. H/P cancel each\n" +
    "  other and themselves. Note that\n" +
    "  dragging an object over others will\n" +
    "  temporarily disturb their\n" +
    "  appearance.\n\n" +
    "M (Mark): tap on the map to\n" +
    "  create a mark. Tap a second\n" +
    "  time to define the direction to\n" +
    "  the next mark.\n\n" +
    "P (Place): drag a boat or mark\n" +
    "  to a new position.\n\n" +
    "R (Rules): display the rules that\n" +
    "  apply to the current scenario.\n\n" +
    "X (Exit): exit from the map screen\n" +
    "  to the main (or previous) screen.";
  private String helpRules =
    "The relative rights of way are\n" +
    "shown for each pair of boats. The\n" +
    "only rules currently supported are\n" +
    "for open water and mark rounding\n" +
    "(not rules 15, 16, 18.4, 18.5, 19).\n\n" +
    "The program takes as its basis\n" +
    "the ISAF 'Racing Rules of Sailing,\n" +
    "2001-2004'. However the output\n" +
    "of the program is purely\n" +
    "indicative, and MUST NOT be\n" +
    "regarded as authoritative.";
  private String helpStart =
    "Use the menu to learn About the\n" +
    "program or to Quit it. Note that it is\n" +
    "possible to leave the program only\n" +
    "via the Quit menu item. If the\n" +
    "current scenario is not saved, you\n" +
    "will be prompted to do this.\n\n" +
    "Enter the wind direction (its origin\n" +
    "as a heading from 0 to 359 degrees\n" +
    "inclusive, default 0) and click Done.\n" +
    "Headings are given in degrees\n" +
    "clockwise from 0 at the top\n" +
    "(0 = North, 90 = East,\n" +
    "180 = South, 270 = West).";

  // basic constructor

  public Help () {
  }

  // return help for given page

  public String getText (int page) {
    String helpText = "";
    switch (page) {
      case SailRule.EDIT_PAGE:
        helpText = helpEdit; break;
      case SailRule.FILE_PAGE:
        helpText = helpFile; break;
      case SailRule.MAIN_PAGE:
        helpText = helpMain; break;
      case SailRule.MAP_PAGE:
        helpText = helpMap; break;
      case SailRule.RULES_PAGE:
        helpText = helpRules; break;
      case SailRule.START_PAGE:
        helpText = helpStart; break;
    }
    return (helpText);
  }
}
