/*********************************************************************

  Rule.java	(C) Kenneth J. Turner, Mark A. Jennings	25/11/01 V1.3

    This class represents a rule.  It has a state-flag combination for
    extraction purposes and a text description.

  KJT 14/08/01:

    o Minor tidy-up of code

    o Rule code separated from rule text

  KJT 25/11/01:

    o Minor tidy-up of code

    o Close-hauled flags added

*********************************************************************/

import waba.ui.*;
import waba.fx.*;
import waba.sys.*;

public class Rule {
  static final int NUM_FLAGS = 15;

  static final int OPPOSITE_TACKS = 0;			// on opposite tacks
  static final int STARBOARD_TACK = 1;			// on starboard tack
  static final int OVERLAPPED = 2;			// overlapped
  static final int CLEAR_AHEAD = 3;			// clear ahead
  static final int TO_LEEWARD = 4;			// to leeward
  static final int TACKING_TO_PORT = 5;			// tacking to port
  static final int TACKING_TO_STARBOARD = 6;		// tacking to starboard
  static final int HEAD_TO_WIND = 7;			// head to wind
  static final int MARK_RULES = 8;			// mark rules apply
  static final int INSIDE_TWO_LENGTHS = 9;		// in zone or near
  static final int ABOVE_PROPER_COURSE = 10;		// above proper course
  static final int BELOW_PROPER_COURSE = 11;		// eblow proper course
  static final int ABOVE_CLOSE_HAULED = 12;		// above close-hauled
  static final int BELOW_CLOSE_HAULED = 13;		// below close-hauled
  static final int PROXIMITY = 14;			// boats too close

  private boolean rFlags[] = new boolean[NUM_FLAGS];
  private String ruleCode;
  private String ruleText;

  // constructor

  public Rule (String code, String text, boolean flags[]) {
    ruleCode = code;
    ruleText = text;
    for (int i = 0 ; i < NUM_FLAGS; i++)
	rFlags[i] = flags[i];
    }

  // get the code from the rule

  public String getCode () {
    return ruleCode;
  }

  // inspect a specific flag

  public boolean getFlag (int index) {
    return rFlags[index];
  }

  // get the text from the rule

  public String getText () {
    return ruleText;
  }
}
